'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _log4js = require('log4js');

var _babelTraverse = require('babel-traverse');

var _babelTraverse2 = _interopRequireDefault(_babelTraverse);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ExtractFunction {

  constructor(opts) {
    this.type = 'extract_function';
    this.ds = opts.documentStorage;
    this.ast = opts.astHelper;
    this.logger = (0, _log4js.getLogger)(this.type);
  }

  suggestCommands(location) {
    const code = this.ds.get(location.uri);
    const fileAst = this.ast.parseCode(code);

    const nodesInsideSelection = [];
    // find nodes inside selection, when its parent outside
    (0, _babelTraverse2.default)(fileAst, {
      enter: path => {
        if (this.ast.isNodeInsideSelection(path.node, location) && !this.ast.isNodeInsideSelection(path.parent, location)) {
          nodesInsideSelection.push(path.node);
        }
      }
    });

    if (nodesInsideSelection.length > 0) {
      console.log(nodesInsideSelection[0]);
      return [{
        title: `Extract function`,
        command: this.type,
        arguments: [location]
      }];
    }

    return [];
  }

  createEdit(args) {
    // TODO check args
    const location = args[0];
    const code = this.ds.get(location.uri);
    const nodes = this.ast.findNodes(code, location);
    const node = nodes.find(n => n.type === 'FunctionDeclaration');

    if (node) {
      const arrowTemplate = 'const NAME = (PARAMS) => BODY';
      const newCode = this.ast.replaceNode(node, code, arrowTemplate, {
        NAME: node.id,
        BODY: node.body,
        PARAMS: node.params
      });

      return (0, _utils.createReplacementEdit)(location.uri, node, newCode);
    }
  }
}
exports.default = ExtractFunction;