'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _babelTypes = require('babel-types');

var t = _interopRequireWildcard(_babelTypes);

var _log4js = require('log4js');

var _utils = require('./utils');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

const DEFAULT_NAME = 'replace_me_name';

class ArrowToFunction {

  constructor(opts) {
    this.type = 'require_to_import';
    this.ds = opts.documentStorage;
    this.ast = opts.astHelper;
    this.logger = (0, _log4js.getLogger)(this.type);
  }

  suggestCommands(location) {
    const code = this.ds.get(location.uri);
    const nodes = this.ast.findNodes(code, location);
    const node = nodes.find(n => n.type === 'CallExpression' && n.callee.name === 'require');

    if (node) {
      return [{
        title: 'Convert to import',
        command: this.type,
        arguments: [location]
      }];
    }

    return [];
  }

  createEdit(args) {
    // TODO check args
    const location = args[0];
    const code = this.ds.get(location.uri);
    const nodes = this.ast.findNodes(code, location);
    const node = nodes.find(n => n.type === 'CallExpression' && n.callee.name === 'require');

    if (node) {
      const index = nodes.indexOf(node);
      const parent = nodes[index + 1];
      if (!t.isVariableDeclarator(parent)) {
        return null;
      }
      const declaration = nodes[index + 2];
      if (!t.isVariableDeclaration(declaration)) {
        return null;
      }

      const name = parent.id;

      // babel-template throws an Error when trying to parse module with templated value
      const template = `import NAME from '${node.arguments[0].value}'`;
      const args = { NAME: name };

      const newCode = this.ast.replaceNode(declaration, code, template, args);

      return (0, _utils.createReplacementEdit)(location.uri, declaration, newCode);
    }
  }
}
exports.default = ArrowToFunction;